Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/pdf
diff options
context:
space:
mode:
authorMiguel de Icaza <miguel@src.gnome.org>2000-02-07 17:29:46 (GMT)
committer Miguel de Icaza <miguel@src.gnome.org>2000-02-07 17:29:46 (GMT)
commit97e4ebaf0f2ac8e8f2bb43d12b017861fae5dfc6 (patch)
treeb7780f46d43072d955275043d7a6bdfb58c01a04 /pdf
parent2a7f38aef3c6a6a96d679b41b181dfbad58d6f8c (diff)
Upgraded to Bonobo-0.7 -miguel
Diffstat (limited to 'pdf')
-rw-r--r--pdf/xpdf/Makefile.in133
-rw-r--r--pdf/xpdf/gpdf.cc126
2 files changed, 127 insertions, 132 deletions
diff --git a/pdf/xpdf/Makefile.in b/pdf/xpdf/Makefile.in
index 083721d..0c29554 100644
--- a/pdf/xpdf/Makefile.in
+++ b/pdf/xpdf/Makefile.in
@@ -1,4 +1,4 @@
-# Makefile.in generated automatically by automake 1.4a from Makefile.am
+# Makefile.in generated automatically by automake 1.4 from Makefile.am
# Copyright (C) 1994, 1995-8, 1999 Free Software Foundation, Inc.
# This Makefile.in is free software; the Free Software Foundation
@@ -46,10 +46,9 @@ AUTOMAKE = @AUTOMAKE@
AUTOHEADER = @AUTOHEADER@
INSTALL = @INSTALL@
-INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@ $(AM_INSTALL_PROGRAM_FLAGS)
INSTALL_DATA = @INSTALL_DATA@
INSTALL_SCRIPT = @INSTALL_SCRIPT@
-INSTALL_STRIP_FLAG =
transform = @program_transform_name@
NORMAL_INSTALL = :
@@ -61,12 +60,20 @@ POST_UNINSTALL = :
host_alias = @host_alias@
host_triplet = @host@
AS = @AS@
+CATALOGS = @CATALOGS@
+CATOBJEXT = @CATOBJEXT@
CC = @CC@
CXX = @CXX@
+DATADIRNAME = @DATADIRNAME@
DLLTOOL = @DLLTOOL@
EXE = @EXE@
+EXTRA_GLIB_CFLAGS = @EXTRA_GLIB_CFLAGS@
+EXTRA_GLIB_LIBS = @EXTRA_GLIB_LIBS@
EXTRA_GNOME_CFLAGS = @EXTRA_GNOME_CFLAGS@
EXTRA_GNOME_LIBS = @EXTRA_GNOME_LIBS@
+GENCAT = @GENCAT@
+GMOFILES = @GMOFILES@
+GMSGFMT = @GMSGFMT@
GNOMEGNORBA_LIBS = @GNOMEGNORBA_LIBS@
GNOMEUI_LIBS = @GNOMEUI_LIBS@
GNOME_APPLETS_LIBS = @GNOME_APPLETS_LIBS@
@@ -81,12 +88,20 @@ GTKXMHTML_LIBS = @GTKXMHTML_LIBS@
GTK_CFLAGS = @GTK_CFLAGS@
GTK_CONFIG = @GTK_CONFIG@
GTK_LIBS = @GTK_LIBS@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
+INSTOBJEXT = @INSTOBJEXT@
+INTLDEPS = @INTLDEPS@
+INTLLIBS = @INTLLIBS@
+INTLOBJS = @INTLOBJS@
LD = @LD@
LIBPREFIX = @LIBPREFIX@
LIBTOOL = @LIBTOOL@
LN_S = @LN_S@
MAINT = @MAINT@
MAKEINFO = @MAKEINFO@
+MKINSTALLDIRS = @MKINSTALLDIRS@
NM = @NM@
OPTIONS = @OPTIONS@
ORBIT_CFLAGS = @ORBIT_CFLAGS@
@@ -94,9 +109,13 @@ ORBIT_CONFIG = @ORBIT_CONFIG@
ORBIT_IDL = @ORBIT_IDL@
ORBIT_LIBS = @ORBIT_LIBS@
PACKAGE = @PACKAGE@
+POFILES = @POFILES@
+POSUB = @POSUB@
PTHREAD_LIB = @PTHREAD_LIB@
RANLIB = @RANLIB@
STRIP = @STRIP@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
USE_SYMBOL_UNDERSCORE = @USE_SYMBOL_UNDERSCORE@
VERSION = @VERSION@
XPM_LIBS = @XPM_LIBS@
@@ -104,13 +123,14 @@ YACC = @YACC@
ZVT_LIBS = @ZVT_LIBS@
cflags_set = @cflags_set@
cxxflags_set = @cxxflags_set@
+l = @l@
-INCLUDES = -I$(top_srcdir)/goo -I$(top_srcdir)/ltk -DGPDF_GLADE_DIR=\""$(gladedir)"\" $(EXTRA_GNOME_CFLAGS)
+INCLUDES = -I$(top_srcdir)/goo -I$(top_srcdir)/ltk $(EXTRA_GLIB_CFLAGS) $(EXTRA_GNOME_CFLAGS)
-@WITH_GNOME_TRUE@gui = gpdf
+@WITH_GNOME_TRUE@gui = xpdf gpdf
@WITH_GNOME_FALSE@gui = xpdf
-bin_PROGRAMS = pdftops pdftotext pdfinfo pdftopbm pdfimages $(gui) bonobo-image-x-pdf
+bin_PROGRAMS = pdftops pdftotext pdfinfo pdftopbm pdfimages $(gui) bonobo-application-x-pdf
common_sources = Array.cc BaseFile.h Catalog.cc Dict.cc Error.cc FontEncoding.cc FontEncoding.h FontFile.cc FontFile.h FontInfo.h Gfx.cc GfxFont.cc GfxState.cc Lexer.cc Link.cc Object.cc OutputDev.cc Page.cc Params.cc Parser.cc PDFDoc.cc Stream.cc TextOutputDev.cc XRef.cc
@@ -124,13 +144,10 @@ gpdf_SOURCES = gpdf.cc
gpdf_LDADD = $(GTK_LIBS) $(GNOME_LIBDIR) -lbonobo $(GNOMEGNORBA_LIBS) $(EXTRA_GNOME_LIBS) $(INTLLIBS)
-bonobo_image_x_pdf_SOURCES = $(common_sources) BonoboStream.h BonoboStream.cc GOutputDev.cc bonobo-image-x-pdf.cc
+bonobo_application_x_pdf_SOURCES = $(common_sources) BonoboStream.h BonoboStream.cc GOutputDev.cc bonobo-application-x-pdf.cc gtkgesture.c gtkgesture.h
-bonobo_image_x_pdf_CFLAGS = -DBONOBO_IO
-
-
-bonobo_image_x_pdf_LDADD = ../goo/libgoo.a $(GTK_LIBS) $(GNOME_LIBDIR) -lbonobo $(GNOMEGNORBA_LIBS) $(INTLLIBS)
+bonobo_application_x_pdf_LDADD = ../goo/libgoo.a $(GTK_LIBS) $(GNOME_LIBDIR) -lbonobo $(GNOMEGNORBA_LIBS) $(EXTRA_GLIB_LIBS) $(INTLLIBS)
xpdf_SOURCES = $(common_sources) XOutputDev.cc LTKOutputDev.cc PSOutputDev.cc xpdf.cc
@@ -167,15 +184,10 @@ bitmaps = about.xbm dblLeftArrow.xbm dblRightArrow.xbm find.xbm leftArro
ltk = xpdf-flip.ltk xpdf-top.ltk xpdf.ltk
-gladedir = $(datadir)/xpdf/glade
-
-glade_DATA = about.glade gpdf.glade
-
-
gnorbadir = $(sysconfdir)/CORBA/servers
-gnorba_DATA = image-x-pdf.gnorba
+gnorba_DATA = application-x-pdf.gnorba
-EXTRA_DIST = $(bitmaps) ChangeLog $(ltk) $(glade_DATA) $(gnorba_DATA)
+EXTRA_DIST = $(bitmaps) ChangeLog $(ltk) $(gnorba_DATA)
mkinstalldirs = $(SHELL) $(top_srcdir)/mkinstalldirs
CONFIG_CLEAN_FILES =
PROGRAMS = $(bin_PROGRAMS)
@@ -219,21 +231,22 @@ OutputDev.o Page.o Params.o Parser.o PDFDoc.o Stream.o TextOutputDev.o \
XRef.o ImageOutputDev.o pdfimages.o
pdfimages_DEPENDENCIES = ../goo/libgoo.a
pdfimages_LDFLAGS =
-gpdf_OBJECTS = gpdf.o
-gpdf_DEPENDENCIES =
-gpdf_LDFLAGS =
xpdf_OBJECTS = Array.o Catalog.o Dict.o Error.o FontEncoding.o \
FontFile.o Gfx.o GfxFont.o GfxState.o Lexer.o Link.o Object.o \
OutputDev.o Page.o Params.o Parser.o PDFDoc.o Stream.o TextOutputDev.o \
XRef.o XOutputDev.o LTKOutputDev.o PSOutputDev.o xpdf.o
xpdf_DEPENDENCIES = ../goo/libgoo.a ../ltk/libltk.a
xpdf_LDFLAGS =
-bonobo_image_x_pdf_OBJECTS = Array.o Catalog.o Dict.o Error.o \
+gpdf_OBJECTS = gpdf.o
+gpdf_DEPENDENCIES =
+gpdf_LDFLAGS =
+bonobo_application_x_pdf_OBJECTS = Array.o Catalog.o Dict.o Error.o \
FontEncoding.o FontFile.o Gfx.o GfxFont.o GfxState.o Lexer.o Link.o \
Object.o OutputDev.o Page.o Params.o Parser.o PDFDoc.o Stream.o \
-TextOutputDev.o XRef.o BonoboStream.o GOutputDev.o bonobo-image-x-pdf.o
-bonobo_image_x_pdf_DEPENDENCIES = ../goo/libgoo.a
-bonobo_image_x_pdf_LDFLAGS =
+TextOutputDev.o XRef.o BonoboStream.o GOutputDev.o \
+bonobo-application-x-pdf.o gtkgesture.o
+bonobo_application_x_pdf_DEPENDENCIES = ../goo/libgoo.a
+bonobo_application_x_pdf_LDFLAGS =
CXXFLAGS = @CXXFLAGS@
CXXCOMPILE = $(CXX) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
LTCXXCOMPILE = $(LIBTOOL) --mode=compile $(CXX) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
@@ -244,7 +257,7 @@ COMPILE = $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CF
LTCOMPILE = $(LIBTOOL) --mode=compile $(CC) $(DEFS) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
CCLD = $(CC)
LINK = $(LIBTOOL) --mode=link $(CCLD) $(AM_CFLAGS) $(CFLAGS) $(LDFLAGS) -o $@
-DATA = $(glade_DATA) $(gnorba_DATA)
+DATA = $(gnorba_DATA)
DIST_COMMON = ChangeLog Makefile.am Makefile.in
@@ -260,11 +273,11 @@ DEP_FILES = .deps/Array.P .deps/BonoboStream.P .deps/Catalog.P \
.deps/Object.P .deps/OutputDev.P .deps/PBMOutputDev.P .deps/PDFDoc.P \
.deps/PSOutputDev.P .deps/Page.P .deps/Params.P .deps/Parser.P \
.deps/Stream.P .deps/TextOutputDev.P .deps/XOutputDev.P .deps/XRef.P \
-.deps/bonobo-image-x-pdf.P .deps/gpdf.P .deps/pdfimages.P \
-.deps/pdfinfo.P .deps/pdftopbm.P .deps/pdftops.P .deps/pdftotext.P \
-.deps/xpdf.P
-SOURCES = $(pdftops_SOURCES) $(pdftotext_SOURCES) $(pdfinfo_SOURCES) $(pdftopbm_SOURCES) $(pdfimages_SOURCES) $(gpdf_SOURCES) $(xpdf_SOURCES) $(bonobo_image_x_pdf_SOURCES)
-OBJECTS = $(pdftops_OBJECTS) $(pdftotext_OBJECTS) $(pdfinfo_OBJECTS) $(pdftopbm_OBJECTS) $(pdfimages_OBJECTS) $(gpdf_OBJECTS) $(xpdf_OBJECTS) $(bonobo_image_x_pdf_OBJECTS)
+.deps/bonobo-application-x-pdf.P .deps/gpdf.P .deps/gtkgesture.P \
+.deps/pdfimages.P .deps/pdfinfo.P .deps/pdftopbm.P .deps/pdftops.P \
+.deps/pdftotext.P .deps/xpdf.P
+SOURCES = $(pdftops_SOURCES) $(pdftotext_SOURCES) $(pdfinfo_SOURCES) $(pdftopbm_SOURCES) $(pdfimages_SOURCES) $(xpdf_SOURCES) $(gpdf_SOURCES) $(bonobo_application_x_pdf_SOURCES)
+OBJECTS = $(pdftops_OBJECTS) $(pdftotext_OBJECTS) $(pdfinfo_OBJECTS) $(pdftopbm_OBJECTS) $(pdfimages_OBJECTS) $(xpdf_OBJECTS) $(gpdf_OBJECTS) $(bonobo_application_x_pdf_OBJECTS)
all: all-redirect
.SUFFIXES:
@@ -291,8 +304,8 @@ install-binPROGRAMS: $(bin_PROGRAMS)
$(mkinstalldirs) $(DESTDIR)$(bindir)
@list='$(bin_PROGRAMS)'; for p in $$list; do \
if test -f $$p; then \
- echo " $(LIBTOOL) --mode=install $(INSTALL_PROGRAM) $(INSTALL_STRIP_FLAG) $$p $(DESTDIR)$(bindir)/`echo $$p|sed 's/$(EXEEXT)$$//'|sed '$(transform)'|sed 's/$$/$(EXEEXT)/'`"; \
- $(LIBTOOL) --mode=install $(INSTALL_PROGRAM) $(INSTALL_STRIP_FLAG) $$p $(DESTDIR)$(bindir)/`echo $$p|sed 's/$(EXEEXT)$$//'|sed '$(transform)'|sed 's/$$/$(EXEEXT)/'`; \
+ echo " $(LIBTOOL) --mode=install $(INSTALL_PROGRAM) $$p $(DESTDIR)$(bindir)/`echo $$p|sed 's/$(EXEEXT)$$//'|sed '$(transform)'|sed 's/$$/$(EXEEXT)/'`"; \
+ $(LIBTOOL) --mode=install $(INSTALL_PROGRAM) $$p $(DESTDIR)$(bindir)/`echo $$p|sed 's/$(EXEEXT)$$//'|sed '$(transform)'|sed 's/$$/$(EXEEXT)/'`; \
else :; fi; \
done
@@ -354,41 +367,26 @@ pdfimages: $(pdfimages_OBJECTS) $(pdfimages_DEPENDENCIES)
@rm -f pdfimages
$(CXXLINK) $(pdfimages_LDFLAGS) $(pdfimages_OBJECTS) $(pdfimages_LDADD) $(LIBS)
+xpdf: $(xpdf_OBJECTS) $(xpdf_DEPENDENCIES)
+ @rm -f xpdf
+ $(CXXLINK) $(xpdf_LDFLAGS) $(xpdf_OBJECTS) $(xpdf_LDADD) $(LIBS)
+
gpdf: $(gpdf_OBJECTS) $(gpdf_DEPENDENCIES)
@rm -f gpdf
$(CXXLINK) $(gpdf_LDFLAGS) $(gpdf_OBJECTS) $(gpdf_LDADD) $(LIBS)
xpdf: $(xpdf_OBJECTS) $(xpdf_DEPENDENCIES)
@rm -f xpdf
- $(CXXLINK) $(xpdf_LDFLAGS) $(xpdf_OBJECTS) $(xpdf_LDADD) $(LIBS)
+ $(LINK) $(xpdf_LDFLAGS) $(xpdf_OBJECTS) $(xpdf_LDADD) $(LIBS)
-bonobo-image-x-pdf: $(bonobo_image_x_pdf_OBJECTS) $(bonobo_image_x_pdf_DEPENDENCIES)
- @rm -f bonobo-image-x-pdf
- $(CXXLINK) $(bonobo_image_x_pdf_LDFLAGS) $(bonobo_image_x_pdf_OBJECTS) $(bonobo_image_x_pdf_LDADD) $(LIBS)
+bonobo-application-x-pdf: $(bonobo_application_x_pdf_OBJECTS) $(bonobo_application_x_pdf_DEPENDENCIES)
+ @rm -f bonobo-application-x-pdf
+ $(CXXLINK) $(bonobo_application_x_pdf_LDFLAGS) $(bonobo_application_x_pdf_OBJECTS) $(bonobo_application_x_pdf_LDADD) $(LIBS)
.cc.o:
$(CXXCOMPILE) -c $<
.cc.lo:
$(LTCXXCOMPILE) -c $<
-install-gladeDATA: $(glade_DATA)
- @$(NORMAL_INSTALL)
- $(mkinstalldirs) $(DESTDIR)$(gladedir)
- @list='$(glade_DATA)'; for p in $$list; do \
- if test -f $(srcdir)/$$p; then \
- echo " $(INSTALL_DATA) $(srcdir)/$$p $(DESTDIR)$(gladedir)/$$p"; \
- $(INSTALL_DATA) $(srcdir)/$$p $(DESTDIR)$(gladedir)/$$p; \
- else if test -f $$p; then \
- echo " $(INSTALL_DATA) $$p $(DESTDIR)$(gladedir)/$$p"; \
- $(INSTALL_DATA) $$p $(DESTDIR)$(gladedir)/$$p; \
- fi; fi; \
- done
-
-uninstall-gladeDATA:
- @$(NORMAL_UNINSTALL)
- list='$(glade_DATA)'; for p in $$list; do \
- rm -f $(DESTDIR)$(gladedir)/$$p; \
- done
-
install-gnorbaDATA: $(gnorba_DATA)
@$(NORMAL_INSTALL)
$(mkinstalldirs) $(DESTDIR)$(gnorbadir)
@@ -450,7 +448,7 @@ distdir: $(DISTFILES)
@for file in $(DISTFILES); do \
d=$(srcdir); \
if test -d $$d/$$file; then \
- cp -pr $$d/$$file $(distdir)/$$file; \
+ cp -pr $$/$$file $(distdir)/$$file; \
else \
test -f $(distdir)/$$file \
|| ln $$d/$$file $(distdir)/$$file 2> /dev/null \
@@ -519,22 +517,20 @@ installcheck: installcheck-am
install-exec-am: install-binPROGRAMS
install-exec: install-exec-am
-install-data-am: install-gladeDATA install-gnorbaDATA
+install-data-am: install-gnorbaDATA
install-data: install-data-am
install-am: all-am
@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
install: install-am
-uninstall-am: uninstall-binPROGRAMS uninstall-gladeDATA \
- uninstall-gnorbaDATA
+uninstall-am: uninstall-binPROGRAMS uninstall-gnorbaDATA
uninstall: uninstall-am
all-am: Makefile $(PROGRAMS) $(DATA)
all-redirect: all-am
install-strip:
- $(MAKE) $(AM_MAKEFLAGS) INSTALL_STRIP_FLAG=-s install
+ $(MAKE) $(AM_MAKEFLAGS) AM_INSTALL_PROGRAM_FLAGS=-s install
installdirs:
- $(mkinstalldirs) $(DESTDIR)$(bindir) $(DESTDIR)$(gladedir) \
- $(DESTDIR)$(gnorbadir)
+ $(mkinstalldirs) $(DESTDIR)$(bindir) $(DESTDIR)$(gnorbadir)
mostlyclean-generic:
@@ -577,12 +573,11 @@ maintainer-clean: maintainer-clean-am
maintainer-clean-binPROGRAMS uninstall-binPROGRAMS install-binPROGRAMS \
mostlyclean-compile distclean-compile clean-compile \
maintainer-clean-compile mostlyclean-libtool distclean-libtool \
-clean-libtool maintainer-clean-libtool uninstall-gladeDATA \
-install-gladeDATA uninstall-gnorbaDATA install-gnorbaDATA tags \
-mostlyclean-tags distclean-tags clean-tags maintainer-clean-tags \
-distdir mostlyclean-depend distclean-depend clean-depend \
-maintainer-clean-depend info-am info dvi-am dvi check check-am \
-installcheck-am installcheck install-exec-am install-exec \
+clean-libtool maintainer-clean-libtool uninstall-gnorbaDATA \
+install-gnorbaDATA tags mostlyclean-tags distclean-tags clean-tags \
+maintainer-clean-tags distdir mostlyclean-depend distclean-depend \
+clean-depend maintainer-clean-depend info-am info dvi-am dvi check \
+check-am installcheck-am installcheck install-exec-am install-exec \
install-data-am install-data install-am install uninstall-am uninstall \
all-redirect all-am all installdirs mostlyclean-generic \
distclean-generic clean-generic maintainer-clean-generic clean \
diff --git a/pdf/xpdf/gpdf.cc b/pdf/xpdf/gpdf.cc
index 332beeb..f1f1831 100644
--- a/pdf/xpdf/gpdf.cc
+++ b/pdf/xpdf/gpdf.cc
@@ -15,7 +15,7 @@ extern "C" {
#include <libgnorba/gnorba.h>
#include <gdk/gdkprivate.h>
#include <gdk/gdkx.h>
-#include <bonobo/gnome-bonobo.h>
+#include <bonobo.h>
#undef GString
}
#include "config.h"
@@ -35,8 +35,8 @@ typedef struct _Container Container;
/* NB. there is a 1 to 1 Container -> Component mapping, this
is due to how much MDI sucks; unutterably */
struct _Container {
- GnomeContainer *container;
- GnomeUIHandler *uih;
+ BonoboContainer *container;
+ BonoboUIHandler *uih;
GtkWidget *app;
GtkScrolledWindow *scroll;
@@ -47,9 +47,9 @@ struct _Container {
struct _Component {
Container *container;
- GnomeClientSite *client_site;
- GnomeViewFrame *view_frame;
- GnomeObjectClient *server;
+ BonoboClientSite *client_site;
+ BonoboViewFrame *view_frame;
+ BonoboObjectClient *server;
};
GList *containers = NULL;
@@ -102,9 +102,9 @@ extern "C" {
static gboolean
open_pdf (Container *container, const char *name)
{
- GnomeObjectClient *object;
- GnomeStream *stream;
- GNOME_PersistStream persist;
+ BonoboObjectClient *object;
+ BonoboStream *stream;
+ Bonobo_PersistStream persist;
Component *comp;
CORBA_Environment ev;
@@ -118,8 +118,8 @@ extern "C" {
}
CORBA_exception_init (&ev);
- persist = GNOME_Unknown_query_interface (
- gnome_object_corba_objref (GNOME_OBJECT (object)),
+ persist = Bonobo_Unknown_query_interface (
+ bonobo_object_corba_objref (BONOBO_OBJECT (object)),
"IDL:GNOME/PersistStream:1.0", &ev);
if (ev._major != CORBA_NO_EXCEPTION ||
@@ -128,7 +128,7 @@ extern "C" {
return FALSE;
}
- stream = gnome_stream_fs_open (name, GNOME_Storage_READ);
+ stream = bonobo_stream_fs_open (name, Bonobo_Storage_READ);
if (stream == NULL) {
char *err = g_strconcat (_("Could not open "), name, NULL);
@@ -137,14 +137,14 @@ extern "C" {
return FALSE;
}
- GNOME_PersistStream_load (persist,
- (GNOME_Stream) gnome_object_corba_objref (GNOME_OBJECT (stream)), &ev);
+ Bonobo_PersistStream_load (persist,
+ (Bonobo_Stream) bonobo_object_corba_objref (BONOBO_OBJECT (stream)), &ev);
- GNOME_Unknown_unref (persist, &ev);
+ Bonobo_Unknown_unref (persist, &ev);
CORBA_Object_release (persist, &ev);
CORBA_exception_free (&ev);
-/* gnome_view_frame_view_do_verb (comp->view_frame, "ZoomFit"); */
+/* bonobo_view_frame_view_do_verb (comp->view_frame, "ZoomFit"); */
return TRUE;
}
@@ -228,15 +228,15 @@ extern "C" {
CORBA_exception_init (&ev);
/* Kill merged menus et al. */
- gnome_view_frame_view_deactivate (component->view_frame);
+ bonobo_view_frame_view_deactivate (component->view_frame);
container = component->container;
gtk_widget_destroy (container->view_widget);
container->view_widget = NULL;
if (component->server)
- GNOME_Unknown_unref (
- gnome_object_corba_objref (GNOME_OBJECT (component->server)), &ev);
+ Bonobo_Unknown_unref (
+ bonobo_object_corba_objref (BONOBO_OBJECT (component->server)), &ev);
component->server = NULL;
CORBA_exception_free (&ev);
@@ -329,28 +329,28 @@ container_about_cmd (GtkWidget *widget, Container *container)
static void
container_set_view (Container *container, Component *component)
{
- GnomeViewFrame *view_frame;
+ BonoboViewFrame *view_frame;
GtkWidget *view_widget;
/*
* Create the remote view and the local ViewFrame.
*/
- view_frame = gnome_client_site_new_view (component->client_site);
+ view_frame = bonobo_client_site_new_view (component->client_site);
component->view_frame = view_frame;
/*
* Set the GnomeUIHandler for this ViewFrame. That way, the
* embedded component can get access to our UIHandler server
* so that it can merge menu and toolbar items when it gets
* activated.
*/
- gnome_view_frame_set_ui_handler (view_frame, container->uih);
+ bonobo_view_frame_set_ui_handler (view_frame, container->uih);
/*
* Embed the view frame into the application.
*/
- view_widget = gnome_view_frame_get_wrapper (view_frame);
- gnome_wrapper_set_visibility (GNOME_WRAPPER (view_widget), FALSE);
+ view_widget = bonobo_view_frame_get_wrapper (view_frame);
+ bonobo_wrapper_set_visibility (BONOBO_WRAPPER (view_widget), FALSE);
container->view_widget = view_widget;
container->component = component;
@@ -362,23 +362,23 @@ container_set_view (Container *container, Component *component)
/*
* Activate it ( get it to merge menus etc. )
*/
- gnome_view_frame_view_activate (view_frame);
- gnome_view_frame_set_covered (view_frame, FALSE);
+ bonobo_view_frame_view_activate (view_frame);
+ bonobo_view_frame_set_covered (view_frame, FALSE);
gtk_widget_show_all (GTK_WIDGET (container->scroll));
}
-static GnomeObjectClient *
-container_launch_component (GnomeClientSite *client_site,
- GnomeContainer *container,
+static BonoboObjectClient *
+container_launch_component (BonoboClientSite *client_site,
+ BonoboContainer *container,
char *component_goad_id)
{
- GnomeObjectClient *object_server;
+ BonoboObjectClient *object_server;
/*
* Launch the component.
*/
- object_server = gnome_object_activate_with_goad_id (
+ object_server = bonobo_object_activate_with_goad_id (
NULL, component_goad_id, GOAD_ACTIVATE_SHLIB, NULL);
if (object_server == NULL)
@@ -386,21 +386,21 @@ container_launch_component (GnomeClientSite *client_site,
/*
* Bind it to the local ClientSite. Every embedded component
* has a local GnomeClientSite object which serves as a
* container-side point of contact for the embeddable. The
* container talks to the embeddable through its ClientSite
*/
- if (!gnome_client_site_bind_embeddable (client_site, object_server)) {
- gnome_object_unref (GNOME_OBJECT (object_server));
+ if (!bonobo_client_site_bind_embeddable (client_site, object_server)) {
+ bonobo_object_unref (BONOBO_OBJECT (object_server));
return NULL;
}
/*
* The GnomeContainer object maintains a list of the
* ClientSites which it manages. Here we add the new
* ClientSite to that list.
*/
- gnome_container_add (container, GNOME_OBJECT (client_site));
+ bonobo_container_add (container, BONOBO_OBJECT (client_site));
return object_server;
}
@@ -410,18 +410,18 @@ extern "C" {
container_activate_component (Container *container, char *component_goad_id)
{
Component *component;
- GnomeClientSite *client_site;
- GnomeObjectClient *server;
+ BonoboClientSite *client_site;
+ BonoboObjectClient *server;
/*
* The ClientSite is the container-side point of contact for
* the Embeddable. So there is a one-to-one correspondence
- * between GnomeClientSites and GnomeEmbeddables. */
- client_site = gnome_client_site_new (container->container);
+ * between BonoboClientSites and BonoboEmbeddables. */
+ client_site = bonobo_client_site_new (container->container);
/*
* A GnomeObjectClient is a simple wrapper for a remote
* GnomeObject (a server supporting GNOME::Unknown).
*/
server = container_launch_component (client_site, container->container,
component_goad_id);
@@ -557,25 +557,25 @@ extern "C" {
*/
} else if (event->keyval == GDK_Home) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_FIRST);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_FIRST);
return TRUE;
} else if (event->keyval == GDK_End) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_LAST);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_LAST);
return TRUE;
} else if (event->keyval == GDK_Page_Down ||
event->keyval == GDK_Next) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_NEXT);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_NEXT);
return TRUE;
} else if (event->keyval == GDK_Page_Up ||
event->keyval == GDK_Prior) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_PREV);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_PREV);
return TRUE;
} else if (event->keyval == GDK_plus ||
event->keyval == GDK_equal) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_Z_IN);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_Z_IN);
} else if (event->keyval == GDK_underscore ||
event->keyval == GDK_minus) {
- gnome_view_frame_view_do_verb (component->view_frame, VERB_Z_OUT);
+ bonobo_view_frame_view_do_verb (component->view_frame, VERB_Z_OUT);
}
return FALSE;
}
@@ -584,27 +584,27 @@ extern "C" {
static void
container_create_menus (Container *container)
{
- GnomeUIHandlerMenuItem *menu_list;
+ BonoboUIHandlerMenuItem *menu_list;
- gnome_ui_handler_create_menubar (container->uih);
+ bonobo_ui_handler_create_menubar (container->uih);
/*
* Create the basic menus out of UIInfo structures.
*/
- menu_list = gnome_ui_handler_menu_parse_uiinfo_list_with_data (container_main_menu, container);
- gnome_ui_handler_menu_add_list (container->uih, "/", menu_list);
- gnome_ui_handler_menu_free_list (menu_list);
+ menu_list = bonobo_ui_handler_menu_parse_uiinfo_list_with_data (container_main_menu, container);
+ bonobo_ui_handler_menu_add_list (container->uih, "/", menu_list);
+ bonobo_ui_handler_menu_free_list (menu_list);
}
static void
container_create_toolbar (Container *container)
{
- GnomeUIHandlerToolbarItem *toolbar;
+ BonoboUIHandlerToolbarItem *toolbar;
- gnome_ui_handler_create_toolbar (container->uih, "pdf");
- toolbar = gnome_ui_handler_toolbar_parse_uiinfo_list_with_data (container_toolbar, container);
- gnome_ui_handler_toolbar_add_list (container->uih, "/pdf/", toolbar);
- gnome_ui_handler_toolbar_free_list (toolbar);
+ bonobo_ui_handler_create_toolbar (container->uih, "pdf");
+ toolbar = bonobo_ui_handler_toolbar_parse_uiinfo_list_with_data (container_toolbar, container);
+ bonobo_ui_handler_toolbar_add_list (container->uih, "/pdf/", toolbar);
+ bonobo_ui_handler_toolbar_free_list (toolbar);
}
static Container *
@@ -635,7 +635,7 @@ container_new (const char *fname)
gtk_window_set_default_size (GTK_WINDOW (container->app), 600, 600);
gtk_window_set_policy (GTK_WINDOW (container->app), TRUE, TRUE, FALSE);
- container->container = gnome_container_new ();
+ container->container = bonobo_container_new ();
container->view_widget = NULL;
container->scroll = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
gtk_scrolled_window_set_policy (container->scroll, GTK_POLICY_ALWAYS,
@@ -649,13 +649,13 @@ container_new (const char *fname)
GTK_SIGNAL_FUNC (container_destroy_cb), container);
/*
* Create the GnomeUIHandler object which will be used to
* create the container's menus and toolbars. The UIHandler
* also creates a CORBA server which embedded components use
* to do menu/toolbar merging.
*/
- container->uih = gnome_ui_handler_new ();
- gnome_ui_handler_set_app (container->uih, GNOME_APP (container->app));
+ container->uih = bonobo_ui_handler_new ();
+ bonobo_ui_handler_set_app (container->uih, GNOME_APP (container->app));
container_create_menus (container);
container_create_toolbar (container);
@@ -329,28 +329,28 @@ container_about_cmd (GtkWidget *widget, Container *container)
component->view_frame = view_frame;
/*
- * Set the GnomeUIHandler for this ViewFrame. That way, the
+ * Set the BonoboUIHandler for this ViewFrame. That way, the
* embedded component can get access to our UIHandler server
* so that it can merge menu and toolbar items when it gets
@@ -386,21 +386,21 @@ container_launch_component (GnomeClientSite *client_site,
/*
* Bind it to the local ClientSite. Every embedded component
- * has a local GnomeClientSite object which serves as a
+ * has a local BonoboClientSite object which serves as a
* container-side point of contact for the embeddable. The
* container talks to the embeddable through its ClientSite
@@ -386,21 +386,21 @@ container_launch_component (GnomeClientSite *client_site,
}
/*
- * The GnomeContainer object maintains a list of the
+ * The BonoboContainer object maintains a list of the
* ClientSites which it manages. Here we add the new
* ClientSite to that list.
@@ -410,18 +410,18 @@ extern "C" {
/*
- * A GnomeObjectClient is a simple wrapper for a remote
- * GnomeObject (a server supporting GNOME::Unknown).
+ * A BonoboObjectClient is a simple wrapper for a remote
+ * BonoboObject (a server supporting Bonobo::Unknown).
*/
server = container_launch_component (client_site, container->container,
@@ -649,13 +649,13 @@ container_new (const char *fname)
GTK_SIGNAL_FUNC (container_destroy_cb), container);
/*
- * Create the GnomeUIHandler object which will be used to
+ * Create the BonoboUIHandler object which will be used to
* create the container's menus and toolbars. The UIHandler
* also creates a CORBA server which embedded components use